@@ -2,8 +2,8 @@
  *
  * SUMMARY.C -  Nagios Alert Summary CGI
  *
- * Copyright (c) 2002-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 10-21-2007
+ * Copyright (c) 2002-2008 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 01-23-2008
  *
  * License:
  * 
@@ -33,6 +33,7 @@
 
 
 extern char main_config_file[MAX_FILENAME_LENGTH];
+extern char url_html_path[MAX_FILENAME_LENGTH];
 extern char url_images_path[MAX_FILENAME_LENGTH];
 extern char url_stylesheets_path[MAX_FILENAME_LENGTH];
 
@@ -708,6 +709,7 @@ void document_header(int use_stylesheet){
 
 	printf("<html>\n");
 	printf("<head>\n");
+	printf("<link rel=\"shortcut icon\" href=\"%sfavicon.ico\" type=\"image/ico\">\n",url_images_path);
 	printf("<title>\n");
 	printf("Nagios Event Summary\n");
 	printf("</title>\n");
@@ -1130,11 +1132,8 @@ int process_cgivars(void){
 				break;
 			        }
 
-			target_hostgroup_name=(char *)malloc(strlen(variables[x])+1);
-			if(target_hostgroup_name==NULL)
+			if((target_hostgroup_name=(char *)strdup(variables[x]))==NULL)
 				target_hostgroup_name="";
-			else
-				strcpy(target_hostgroup_name,variables[x]);
 			strip_html_brackets(target_hostgroup_name);
 
 			if(!strcmp(target_hostgroup_name,"all"))
@@ -1153,11 +1152,8 @@ int process_cgivars(void){
 				break;
 			        }
 
-			target_servicegroup_name=(char *)malloc(strlen(variables[x])+1);
-			if(target_servicegroup_name==NULL)
+			if((target_servicegroup_name=(char *)strdup(variables[x]))==NULL)
 				target_servicegroup_name="";
-			else
-				strcpy(target_servicegroup_name,variables[x]);
 			strip_html_brackets(target_servicegroup_name);
 
 			if(!strcmp(target_servicegroup_name,"all"))
@@ -1176,11 +1172,8 @@ int process_cgivars(void){
 				break;
 			        }
 
-			target_host_name=(char *)malloc(strlen(variables[x])+1);
-			if(target_host_name==NULL)
+			if((target_host_name=(char *)strdup(variables[x]))==NULL)
 				target_host_name="";
-			else
-				strcpy(target_host_name,variables[x]);
 			strip_html_brackets(target_host_name);
 
 			if(!strcmp(target_host_name,"all"))
