@@ -2,8 +2,8 @@
  *
  * TAC.C - Nagios Tactical Monitoring Overview CGI
  *
- * Copyright (c) 2001-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-21-2006
+ * Copyright (c) 2001-2008 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 01-08-2008
  *
  * This CGI program will display the contents of the Nagios
  * log file.
@@ -47,6 +47,7 @@ typedef struct hostoutage_struct{
 
 
 extern char   main_config_file[MAX_FILENAME_LENGTH];
+extern char   url_html_path[MAX_FILENAME_LENGTH];
 extern char   url_images_path[MAX_FILENAME_LENGTH];
 extern char   url_stylesheets_path[MAX_FILENAME_LENGTH];
 extern char   url_media_path[MAX_FILENAME_LENGTH];
@@ -186,12 +187,20 @@ int services_critical_unacknowledged=0;
 int services_critical=0;
 
 
+/*efine DEBUG 1*/
 
 int main(void){
 	int result=OK;
 	char *sound=NULL;
+#ifdef DEBUG
+	time_t t1,t2,t3,t4,t5,t6,t7,t8,t9;
+#endif
 
 
+#ifdef DEBUG
+	time(&t1);
+#endif
+
 	/* get the CGI variables passed in the URL */
 	process_cgivars();
 
@@ -207,6 +216,10 @@ int main(void){
 		return ERROR;
 	        }
 
+#ifdef DEBUG
+	time(&t2);
+#endif
+
 	/* read the main configuration file */
 	result=read_main_config_file(main_config_file);
 	if(result==ERROR){
@@ -216,6 +229,10 @@ int main(void){
 		return ERROR;
 	        }
 
+#ifdef DEBUG
+	time(&t3);
+#endif
+
 	/* read all object configuration data */
 	result=read_all_object_configuration_data(main_config_file,READ_ALL_OBJECT_DATA);
 	if(result==ERROR){
@@ -225,6 +242,10 @@ int main(void){
 		return ERROR;
                 }
 
+#ifdef DEBUG
+	time(&t4);
+#endif
+
 	/* read all status data */
 	result=read_all_status_data(get_cgi_config_location(),READ_ALL_STATUS_DATA);
 	if(result==ERROR){
@@ -235,6 +256,10 @@ int main(void){
 		return ERROR;
                 }
 
+#ifdef DEBUG
+	time(&t5);
+#endif
+
 	document_header(TRUE);
 
 	/* get authentication information */
@@ -267,13 +292,25 @@ int main(void){
 	        }
 
 
+#ifdef DEBUG
+	time(&t6);
+#endif
+
 	/* analyze current host and service status data for tac overview */
 	analyze_status_data();
 
+#ifdef DEBUG
+	time(&t7);
+#endif
+
 	/* find all hosts that are causing network outages */
 	find_hosts_causing_outages();
 
 
+#ifdef DEBUG
+	time(&t8);
+#endif
+
         /* embed sound tag if necessary... */
 	if(hosts_unreachable_unacknowledged > 0 && host_unreachable_sound!=NULL)
 		sound=host_unreachable_sound;
@@ -285,13 +322,22 @@ int main(void){
 		sound=service_warning_sound;
 	else if(services_unknown_unacknowledged==0 && services_warning_unacknowledged==0 && services_critical_unacknowledged==0 && hosts_down_unacknowledged==0 && hosts_unreachable_unacknowledged==0 && normal_sound!=NULL)
 		sound=normal_sound;
-	if(sound!=NULL)
-		printf("<EMBED SRC='%s%s' HIDDEN=TRUE AUTOSTART=TRUE>",url_media_path,sound);
+	if(sound!=NULL){
+		printf("<object type=\"application/wav\" height=\"-\" width=\"0\">");
+		printf("<param name=\"filename\" value=\"%s%s\">",url_media_path,sound);
+		printf("<param name=\"autostart\" value=\"1\">");
+		printf("<param name=\"playcount\" value=\"1\">");
+		printf("</object>");
+		}
 
 
 	/**** display main tac screen ****/
 	display_tac_overview();
 
+#ifdef DEBUG
+	time(&t9);
+#endif
+
 	document_footer();
 
 	/* free memory allocated to the host outage list */
@@ -299,6 +345,18 @@ int main(void){
 
 	/* free allocated memory */
 	free_memory();
+
+#ifdef DEBUG
+	printf("T1: %lu\n",(unsigned long)t1);
+	printf("T2: %lu\n",(unsigned long)t2);
+	printf("T3: %lu\n",(unsigned long)t3);
+	printf("T4: %lu\n",(unsigned long)t4);
+	printf("T5: %lu\n",(unsigned long)t5);
+	printf("T6: %lu\n",(unsigned long)t6);
+	printf("T7: %lu\n",(unsigned long)t7);
+	printf("T8: %lu\n",(unsigned long)t8);
+	printf("T9: %lu\n",(unsigned long)t9);
+#endif
 	
 	return OK;
         }
@@ -330,6 +388,7 @@ void document_header(int use_stylesheet){
 
 	printf("<HTML>\n");
 	printf("<HEAD>\n");
+	printf("<link rel=\"shortcut icon\" href=\"%sfavicon.ico\" type=\"image/ico\">\n",url_images_path);
 	printf("<TITLE>\n");
 	printf("Nagios Tactical Monitoring Overview\n");
 	printf("</TITLE>\n");
