@@ -3,7 +3,7 @@
  * COMMENTS.C - Comment functions for Nagios
  *
  * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-21-2006
+ * Last Modified: 10-19-2007
  *
  * License:
  *
@@ -58,7 +58,7 @@ comment     **comment_hashlist=NULL;
 
 /* initializes comment data */
 int initialize_comment_data(char *config_file){
-	int result;
+	int result=OK;
 
 	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
 #ifdef USE_XCDDEFAULT
@@ -71,7 +71,7 @@ int initialize_comment_data(char *config_file){
 
 /* removes old/invalid comments */
 int cleanup_comment_data(char *config_file){
-	int result;
+	int result=OK;
 	
 	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
 #ifdef USE_XCDDEFAULT
@@ -90,8 +90,8 @@ int cleanup_comment_data(char *config_file){
 
 /* adds a new host or service comment */
 int add_new_comment(int type, int entry_type, char *host_name, char *svc_description, time_t entry_time, char *author_name, char *comment_data, int persistent, int source, int expires, time_t expire_time, unsigned long *comment_id){
-	int result;
-	unsigned long new_comment_id;
+	int result=OK;
+	unsigned long new_comment_id=0L;
 
 	if(type==HOST_COMMENT)
 		result=add_new_host_comment(entry_type,host_name,entry_time,author_name,comment_data,persistent,source,expires,expire_time,&new_comment_id);
@@ -100,7 +100,7 @@ int add_new_comment(int type, int entry_type, char *host_name, char *svc_descrip
 
 	/* add an event to expire comment data if necessary... */
 	if(expires==TRUE)
-		schedule_new_event(EVENT_EXPIRE_COMMENT,FALSE,expire_time,FALSE,0,NULL,TRUE,(void *)new_comment_id,NULL);
+		schedule_new_event(EVENT_EXPIRE_COMMENT,FALSE,expire_time,FALSE,0,NULL,TRUE,(void *)new_comment_id,NULL,0);
 
 	/* save comment id */
 	if(comment_id!=NULL)
@@ -112,8 +112,8 @@ int add_new_comment(int type, int entry_type, char *host_name, char *svc_descrip
 
 /* adds a new host comment */
 int add_new_host_comment(int entry_type, char *host_name, time_t entry_time, char *author_name, char *comment_data, int persistent, int source, int expires, time_t expire_time, unsigned long *comment_id){
-	int result;
-	unsigned long new_comment_id;
+	int result=OK;
+	unsigned long new_comment_id=0L;
 
 	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
 #ifdef USE_XCDDEFAULT
@@ -135,8 +135,8 @@ int add_new_host_comment(int entry_type, char *host_name, time_t entry_time, cha
 
 /* adds a new service comment */
 int add_new_service_comment(int entry_type, char *host_name, char *svc_description, time_t entry_time, char *author_name, char *comment_data, int persistent, int source, int expires, time_t expire_time, unsigned long *comment_id){
-	int result;
-	unsigned long new_comment_id;
+	int result=OK;
+	unsigned long new_comment_id=0L;
 
 	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
 #ifdef USE_XCDDEFAULT
@@ -164,11 +164,11 @@ int add_new_service_comment(int entry_type, char *host_name, char *svc_descripti
 
 /* deletes a host or service comment */
 int delete_comment(int type, unsigned long comment_id){
-	int result;
+	int result=OK;
 	comment *this_comment=NULL;
 	comment *last_comment=NULL;
 	comment *next_comment=NULL;
-	int hashslot;
+	int hashslot=0;
 	comment *this_hash=NULL;
 	comment *last_hash=NULL;
 
@@ -192,7 +192,7 @@ int delete_comment(int type, unsigned long comment_id){
 #endif
 
 		/* first remove from chained hash list */
-		hashslot=hashfunc1(this_comment->host_name,COMMENT_HASHSLOTS);
+		hashslot=hashfunc(this_comment->host_name,NULL,COMMENT_HASHSLOTS);
 		last_hash=NULL;
 		for(this_hash=comment_hashlist[hashslot];this_hash;this_hash=this_hash->nexthash){
 			if(this_hash==this_comment){
@@ -212,11 +212,11 @@ int delete_comment(int type, unsigned long comment_id){
 			last_comment->next=next_comment;
 		
 		/* free memory */
-		free(this_comment->host_name);
-		free(this_comment->service_description);
-		free(this_comment->author);
-		free(this_comment->comment_data);
-		free(this_comment);
+		my_free(this_comment->host_name);
+		my_free(this_comment->service_description);
+		my_free(this_comment->author);
+		my_free(this_comment->comment_data);
+		my_free(this_comment);
 
 		result=OK;
 	        }
@@ -237,10 +237,10 @@ int delete_comment(int type, unsigned long comment_id){
 
 /* deletes a host comment */
 int delete_host_comment(unsigned long comment_id){
-	int result;
+	int result=OK;
 
 	/* delete the comment from memory */
-	delete_comment(HOST_COMMENT,comment_id);
+	result=delete_comment(HOST_COMMENT,comment_id);
 	
 	return result;
         }
@@ -249,10 +249,10 @@ int delete_host_comment(unsigned long comment_id){
 
 /* deletes a service comment */
 int delete_service_comment(unsigned long comment_id){
-	int result;
+	int result=OK;
 	
 	/* delete the comment from memory */
-	delete_comment(SERVICE_COMMENT,comment_id);
+	result=delete_comment(SERVICE_COMMENT,comment_id);
 	
 	return result;
         }
@@ -260,7 +260,7 @@ int delete_service_comment(unsigned long comment_id){
 
 /* deletes all comments for a particular host or service */
 int delete_all_comments(int type, char *host_name, char *svc_description){
-	int result;
+	int result=OK;
 
 	if(type==HOST_COMMENT)
 		result=delete_all_host_comments(host_name);
@@ -273,7 +273,7 @@ int delete_all_comments(int type, char *host_name, char *svc_description){
 
 /* deletes all comments for a particular host */
 int delete_all_host_comments(char *host_name){
-	int result;
+	int result=OK;
 	comment *temp_comment=NULL;
 
 	if(host_name==NULL)
@@ -285,10 +285,23 @@ int delete_all_host_comments(char *host_name){
 			delete_comment(HOST_COMMENT,temp_comment->comment_id);
 	        }
 
-	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
-#ifdef USE_XCDDEFAULT
-	result=xcddefault_delete_all_host_comments(host_name);
-#endif
+	return result;
+        }
+
+
+/* deletes all non-persistent acknowledgement comments for a particular host */
+int delete_host_acknowledgement_comments(host *hst){
+	int result=OK;
+	comment *temp_comment=NULL;
+
+	if(hst==NULL)
+		return ERROR;
+	
+	/* delete comments from memory */
+	for(temp_comment=get_first_comment_by_host(hst->name);temp_comment!=NULL;temp_comment=get_next_comment_by_host(hst->name,temp_comment)){
+		if(temp_comment->comment_type==HOST_COMMENT && temp_comment->entry_type==ACKNOWLEDGEMENT_COMMENT && temp_comment->persistent==FALSE)
+			delete_comment(HOST_COMMENT,temp_comment->comment_id);
+	        }
 
 	return result;
         }
@@ -296,7 +309,7 @@ int delete_all_host_comments(char *host_name){
 
 /* deletes all comments for a particular service */
 int delete_all_service_comments(char *host_name, char *svc_description){
-	int result;
+	int result=OK;
 	comment *temp_comment=NULL;
 	comment *next_comment=NULL;
 
@@ -309,17 +322,26 @@ int delete_all_service_comments(char *host_name, char *svc_description){
 		if(temp_comment->comment_type==SERVICE_COMMENT && !strcmp(temp_comment->host_name,host_name) && !strcmp(temp_comment->service_description,svc_description))
 			delete_comment(SERVICE_COMMENT,temp_comment->comment_id);
 	        }
-#ifdef REMOVED_032106
-	for(temp_comment=get_first_comment_by_host(host_name);temp_comment!=NULL;temp_comment=get_next_comment_by_host(host_name,temp_comment)){
-		if(temp_comment->comment_type==SERVICE_COMMENT && !strcmp(temp_comment->service_description,svc_description))
+
+	return result;
+        }
+
+
+/* deletes all non-persistent acknowledgement comments for a particular service */
+int delete_service_acknowledgement_comments(service *svc){
+	int result=OK;
+	comment *temp_comment=NULL;
+	comment *next_comment=NULL;
+
+	if(svc==NULL)
+		return ERROR;
+	
+	/* delete comments from memory */
+	for(temp_comment=comment_list;temp_comment!=NULL;temp_comment=next_comment){
+		next_comment=temp_comment->next;
+		if(temp_comment->comment_type==SERVICE_COMMENT && !strcmp(temp_comment->host_name,svc->host_name) && !strcmp(temp_comment->service_description,svc->description)  && temp_comment->entry_type==ACKNOWLEDGEMENT_COMMENT && temp_comment->persistent==FALSE)
 			delete_comment(SERVICE_COMMENT,temp_comment->comment_id);
 	        }
-#endif
-
-	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
-#ifdef USE_XCDDEFAULT
-	result=xcddefault_delete_all_service_comments(host_name,svc_description);
-#endif
 
 	return result;
         }
@@ -327,7 +349,7 @@ int delete_all_service_comments(char *host_name, char *svc_description){
 
 /* checks for an expired comment (and removes it) */
 int check_for_expired_comment(unsigned long comment_id){
-	comment *temp_comment;
+	comment *temp_comment=NULL;
 
 	/* check all comments */
 	for(temp_comment=comment_list;temp_comment!=NULL;temp_comment=temp_comment->next){
@@ -348,23 +370,6 @@ int check_for_expired_comment(unsigned long comment_id){
 
 
 
-/******************************************************************/
-/********************** INPUT FUNCTIONS ***************************/
-/******************************************************************/
-
-
-int read_comment_data(char *main_config_file){
-	int result;
-
-	/**** IMPLEMENTATION-SPECIFIC CALLS ****/
-#ifdef USE_XCDDEFAULT
-	result=xcddefault_read_comment_data(main_config_file);
-#endif
-
-	return result;
-        }
-
-
 
 /******************************************************************/
 /****************** CHAINED HASH FUNCTIONS ************************/
@@ -372,8 +377,9 @@ int read_comment_data(char *main_config_file){
 
 /* adds comment to hash list in memory */
 int add_comment_to_hashlist(comment *new_comment){
-	comment *temp_comment, *lastpointer;
-	int hashslot;
+	comment *temp_comment=NULL;
+	comment *lastpointer=NULL;
+	int hashslot=0;
 
 	/* initialize hash list */
 	if(comment_hashlist==NULL){
@@ -390,10 +396,10 @@ int add_comment_to_hashlist(comment *new_comment){
 	if(!new_comment)
 		return 0;
 
-	hashslot=hashfunc1(new_comment->host_name,COMMENT_HASHSLOTS);
+	hashslot=hashfunc(new_comment->host_name,NULL,COMMENT_HASHSLOTS);
 	lastpointer=NULL;
-	for(temp_comment=comment_hashlist[hashslot];temp_comment && compare_hashdata1(temp_comment->host_name,new_comment->host_name)<0;temp_comment=temp_comment->nexthash){
-		if(compare_hashdata1(temp_comment->host_name,new_comment->host_name)>=0)
+	for(temp_comment=comment_hashlist[hashslot];temp_comment && compare_hashdata(temp_comment->host_name,NULL,new_comment->host_name,NULL)<0;temp_comment=temp_comment->nexthash){
+		if(compare_hashdata(temp_comment->host_name,NULL,new_comment->host_name,NULL)>=0)
 			break;
 		lastpointer=temp_comment;
 	        }
@@ -417,7 +423,7 @@ int add_comment_to_hashlist(comment *new_comment){
 
 /* adds a host comment to the list in memory */
 int add_host_comment(int entry_type, char *host_name, time_t entry_time, char *author, char *comment_data, unsigned long comment_id, int persistent, int expires, time_t expire_time, int source){
-	int result;
+	int result=OK;
 
 	result=add_comment(HOST_COMMENT,entry_type,host_name,NULL,entry_time,author,comment_data,comment_id,persistent,expires,expire_time,source);
 
@@ -428,7 +434,7 @@ int add_host_comment(int entry_type, char *host_name, time_t entry_time, char *a
 
 /* adds a service comment to the list in memory */
 int add_service_comment(int entry_type, char *host_name, char *svc_description, time_t entry_time, char *author, char *comment_data, unsigned long comment_id, int persistent, int expires, time_t expire_time, int source){
-	int result;
+	int result=OK;
 
 	result=add_comment(SERVICE_COMMENT,entry_type,host_name,svc_description,entry_time,author,comment_data,comment_id,persistent,expires,expire_time,source);
 
@@ -442,51 +448,35 @@ int add_comment(int comment_type, int entry_type, char *host_name, char *svc_des
 	comment *new_comment=NULL;
 	comment *last_comment=NULL;
 	comment *temp_comment=NULL;
+	int result=OK;
 
 	/* make sure we have the data we need */
 	if(host_name==NULL || author==NULL || comment_data==NULL || (comment_type==SERVICE_COMMENT && svc_description==NULL))
 		return ERROR;
 
 	/* allocate memory for the comment */
-	new_comment=(comment *)malloc(sizeof(comment));
-	if(new_comment==NULL)
+	if((new_comment=(comment *)malloc(sizeof(comment)))==NULL)
 		return ERROR;
 
-	new_comment->host_name=strdup(host_name);
-	if(new_comment->host_name==NULL){
-		free(new_comment);
-		return ERROR;
-	        }
+	/* initialize vars */
+	new_comment->host_name=NULL;
+	new_comment->service_description=NULL;
+	new_comment->author=NULL;
+	new_comment->comment_data=NULL;
+	new_comment->next=NULL;
+	new_comment->nexthash=NULL;
 
+	/* duplicate vars */
+	if((new_comment->host_name=(char *)strdup(host_name))==NULL)
+		result=ERROR;
 	if(comment_type==SERVICE_COMMENT){
-		new_comment->service_description=strdup(svc_description);
-		if(new_comment->service_description==NULL){
-			free(new_comment->host_name);
-			free(new_comment);
-			return ERROR;
-		        }
-	        }
-	else
-		new_comment->service_description=NULL;
-
-	new_comment->author=strdup(author);
-	if(new_comment->author==NULL){
-		if(new_comment->service_description!=NULL)
-			free(new_comment->service_description);
-		free(new_comment->host_name);
-		free(new_comment);
-		return ERROR;
-	        }
-
-	new_comment->comment_data=strdup(comment_data);
-	if(new_comment->comment_data==NULL){
-		free(new_comment->author);
-		if(new_comment->service_description!=NULL)
-			free(new_comment->service_description);
-		free(new_comment->host_name);
-		free(new_comment);
-		return ERROR;
+		if((new_comment->service_description=(char *)strdup(svc_description))==NULL)
+			result=ERROR;
 	        }
+	if((new_comment->author=(char *)strdup(author))==NULL)
+		result=ERROR;
+	if((new_comment->comment_data=(char *)strdup(comment_data))==NULL)
+		result=ERROR;
 
 	new_comment->comment_type=comment_type;
 	new_comment->entry_type=entry_type;
@@ -497,12 +487,21 @@ int add_comment(int comment_type, int entry_type, char *host_name, char *svc_des
 	new_comment->expires=(expires==TRUE)?TRUE:FALSE;
 	new_comment->expire_time=expire_time;
 
-	new_comment->next=NULL;
-	new_comment->nexthash=NULL;
-
 	/* add comment to hash list */
-	if(!add_comment_to_hashlist(new_comment))
+	if(result==OK){
+		if(!add_comment_to_hashlist(new_comment))
+			result=ERROR;
+	        }
+
+	/* handle errors */
+	if(result==ERROR){
+		my_free(new_comment->comment_data);
+		my_free(new_comment->author);
+		my_free(new_comment->service_description);
+		my_free(new_comment->host_name);
+		my_free(new_comment);
 		return ERROR;
+	        }
 
 	/* add new comment to comment list, sorted by comment id */
 	last_comment=comment_list;
@@ -546,21 +545,21 @@ int add_comment(int comment_type, int entry_type, char *host_name, char *svc_des
 
 /* frees memory allocated for the comment data */
 void free_comment_data(void){
-	comment *this_comment;
-	comment *next_comment;
+	comment *this_comment=NULL;
+	comment *next_comment=NULL;
 
 	/* free memory for the comment list */
 	for(this_comment=comment_list;this_comment!=NULL;this_comment=next_comment){
 		next_comment=this_comment->next;
-		free(this_comment->host_name);
-		free(this_comment->service_description);
-		free(this_comment->author);
-		free(this_comment->comment_data);
-		free(this_comment);
+		my_free(this_comment->host_name);
+		my_free(this_comment->service_description);
+		my_free(this_comment->author);
+		my_free(this_comment->comment_data);
+		my_free(this_comment);
 	        }
 
 	/* free hash list and reset list pointer */
-	free(comment_hashlist);
+	my_free(comment_hashlist);
 	comment_hashlist=NULL;
 	comment_list=NULL;
 
@@ -576,7 +575,7 @@ void free_comment_data(void){
 
 /* get the number of comments associated with a particular host */
 int number_of_host_comments(char *host_name){
-	comment *temp_comment;
+	comment *temp_comment=NULL;
 	int total_comments=0;
 
 	if(host_name==NULL)
@@ -593,7 +592,7 @@ int number_of_host_comments(char *host_name){
 
 /* get the number of comments associated with a particular service */
 int number_of_service_comments(char *host_name, char *svc_description){
-	comment *temp_comment;
+	comment *temp_comment=NULL;
 	int total_comments=0;
 
 	if(host_name==NULL || svc_description==NULL)
@@ -620,19 +619,19 @@ comment *get_first_comment_by_host(char *host_name){
 
 
 comment *get_next_comment_by_host(char *host_name, comment *start){
-	comment *temp_comment;
+	comment *temp_comment=NULL;
 
 	if(host_name==NULL || comment_hashlist==NULL)
 		return NULL;
 
 	if(start==NULL)
-		temp_comment=comment_hashlist[hashfunc1(host_name,COMMENT_HASHSLOTS)];
+		temp_comment=comment_hashlist[hashfunc(host_name,NULL,COMMENT_HASHSLOTS)];
 	else
 		temp_comment=start->nexthash;
 
-	for(;temp_comment && compare_hashdata1(temp_comment->host_name,host_name)<0;temp_comment=temp_comment->nexthash);
+	for(;temp_comment && compare_hashdata(temp_comment->host_name,NULL,host_name,NULL)<0;temp_comment=temp_comment->nexthash);
 
-	if(temp_comment && compare_hashdata1(temp_comment->host_name,host_name)==0)
+	if(temp_comment && compare_hashdata(temp_comment->host_name,NULL,host_name,NULL)==0)
 		return temp_comment;
 
 	return NULL;
@@ -660,7 +659,7 @@ comment *find_host_comment(unsigned long comment_id){
 
 /* find a comment by id */
 comment *find_comment(unsigned long comment_id, int comment_type){
-	comment *temp_comment;
+	comment *temp_comment=NULL;
 
 	for(temp_comment=comment_list;temp_comment!=NULL;temp_comment=temp_comment->next){
 		if(temp_comment->comment_id==comment_id && temp_comment->comment_type==comment_type)
