@@ -2,7 +2,8 @@
  *
  * COMMENTS.H - Header file for comment functions
  *
- * Last Modified:   12-15-2005
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   12-26-2006
  *
  * License:
  *
@@ -94,7 +95,10 @@ int delete_host_comment(unsigned long);                             /* deletes a
 int delete_service_comment(unsigned long);                          /* deletes a service comment */
 int delete_all_comments(int,char *,char *);                         /* deletes all comments for a particular host or service */
 int delete_all_host_comments(char *);                               /* deletes all comments for a specific host */
+int delete_host_acknowledgement_comments(host *);                   /* deletes all non-persistent ack comments for a specific host */
 int delete_all_service_comments(char *,char *);                     /* deletes all comments for a specific service */
+int delete_service_acknowledgement_comments(service *);             /* deletes all non-persistent ack comments for a specific service */
+
 int check_for_expired_comment(unsigned long);                       /* expires a comment */
 #endif
 
@@ -108,8 +112,6 @@ comment *get_next_comment_by_host(char *,comment *);
 int number_of_host_comments(char *);			              /* returns the number of comments associated with a particular host */
 int number_of_service_comments(char *, char *);		              /* returns the number of comments associated with a particular service */
 
-int read_comment_data(char *);                                            /* reads all host and service comments */
-
 int add_comment(int,int,char *,char *,time_t,char *,char *,unsigned long,int,int,time_t,int);      /* adds a comment (host or service) */
 int add_host_comment(int,char *,time_t,char *,char *,unsigned long,int,int,time_t,int);            /* adds a host comment */
 int add_service_comment(int,char *,char *,time_t,char *,char *,unsigned long,int,int,time_t,int);  /* adds a service comment */
