@@ -54,8 +54,16 @@ int nebmodule_init(int flags, char *args, nebmodule *handle){
 	/* save our handle */
 	helloworld_module_handle=handle;
 
+	/* set some info - this is completely optional, as Nagios doesn't do anything with this data */
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_TITLE,"helloworld");
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_AUTHOR,"Ethan Galstad");
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_TITLE,"Copyright (c) 2003-2007 Ethan Galstad");
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_VERSION,"noversion");
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_LICENSE,"GPL v2");
+	neb_set_module_info(helloworld_module_handle,NEBMODULE_MODINFO_DESC,"A simple example to get you started with Nagios Event Broker (NEB) modules.");
+
 	/* log module info to the Nagios log file */
-	write_to_all_logs("helloworld: Copyright (c) 2003-2005 Ethan Galstad (nagios@nagios.org)",NSLOG_INFO_MESSAGE);
+	write_to_all_logs("helloworld: Copyright (c) 2003-2007 Ethan Galstad (nagios@nagios.org)",NSLOG_INFO_MESSAGE);
 	
 	/* log a message to the Nagios log file */
 	snprintf(temp_buffer,sizeof(temp_buffer)-1,"helloworld: Hello world!\n");
@@ -65,7 +73,7 @@ int nebmodule_init(int flags, char *args, nebmodule *handle){
 	/* log a reminder message every 15 minutes (how's that for annoying? :-)) */
 	time(&current_time);
 	interval=900;
-	schedule_new_event(EVENT_USER_FUNCTION,TRUE,current_time+interval,TRUE,interval,NULL,TRUE,(void *)helloworld_reminder_message,"How about you?");
+	schedule_new_event(EVENT_USER_FUNCTION,TRUE,current_time+interval,TRUE,interval,NULL,TRUE,(void *)helloworld_reminder_message,"How about you?",0);
 
 	/* register to be notified of certain events... */
 	neb_register_callback(NEBCALLBACK_AGGREGATED_STATUS_DATA,helloworld_module_handle,0,helloworld_handle_data);
