@@ -2,8 +2,8 @@
  *
  * XRDDEFAULT.H - Header file for default state retention routines
  *
- * Copyright (c) 1999-2003 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   02-12-2003
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   03-01-2006
  *
  * License:
  *
@@ -22,14 +22,26 @@
  *
  *****************************************************************************/
 
+#ifndef _XRDDEFAULT_H
+#define _XRDDEFAULT_H
 
-#define XRDDEFAULT_NO_DATA          0
-#define XRDDEFAULT_INFO_DATA        1
-#define XRDDEFAULT_PROGRAM_DATA     2
-#define XRDDEFAULT_HOST_DATA        3
-#define XRDDEFAULT_SERVICE_DATA     4
 
+#define XRDDEFAULT_NO_DATA               0
+#define XRDDEFAULT_INFO_DATA             1
+#define XRDDEFAULT_PROGRAMSTATUS_DATA    2
+#define XRDDEFAULT_HOSTSTATUS_DATA       3
+#define XRDDEFAULT_SERVICESTATUS_DATA    4
+#define XRDDEFAULT_CONTACTSTATUS_DATA    5
+#define XRDDEFAULT_HOSTCOMMENT_DATA      6
+#define XRDDEFAULT_SERVICECOMMENT_DATA   7
+#define XRDDEFAULT_HOSTDOWNTIME_DATA     8
+#define XRDDEFAULT_SERVICEDOWNTIME_DATA  9
+
+int xrddefault_initialize_retention_data(char *);
+int xrddefault_cleanup_retention_data(char *);
 int xrddefault_grab_config_info(char *);
-int xrddefault_save_state_information(char *);        /* saves all host and service state information */
-int xrddefault_read_state_information(char *);        /* reads in initial host and service state information */
+int xrddefault_grab_config_directives(char *);
+int xrddefault_save_state_information(void);        /* saves all host and service state information */
+int xrddefault_read_state_information(void);        /* reads in initial host and service state information */
 
+#endif
